// Copyright 2019, Collabora, Ltd.
// SPDX-License-Identifier: BSL-1.0
/*!
 * @file
 * @brief  OpenGL API wrapper header.
 * @author Jakob Bornecrantz <jakob@collabora.com>
 * @ingroup aux_ogl
 */

#pragma once

#include "glad/gl.h" // IWYU pragma: export
